@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 
 Created on Fri Jul 05 14:05:24 2013
@@ -92,22 +91,22 @@ def test_mcnemar_chisquare():
 
 def test_mcnemar_vectorized(reset_randomstate):
     ttk = np.random.randint(5,15, size=(2,2,3))
-    with pytest.deprecated_call():
+    with pytest.warns(FutureWarning):
         res = sbmcnemar(ttk, exact=False)
-    with pytest.deprecated_call():
+    with pytest.warns(FutureWarning):
         res1 = lzip(*[sbmcnemar(ttk[:, :, i], exact=False) for i in range(3)])
     assert_allclose(res, res1, rtol=1e-13)
 
-    with pytest.deprecated_call():
+    with pytest.warns(FutureWarning):
         res = sbmcnemar(ttk, exact=False, correction=False)
-    with pytest.deprecated_call():
+    with pytest.warns(FutureWarning):
         res1 = lzip(*[sbmcnemar(ttk[:, :, i], exact=False, correction=False)
                       for i in range(3)])
     assert_allclose(res, res1, rtol=1e-13)
 
-    with pytest.deprecated_call():
+    with pytest.warns(FutureWarning):
         res = sbmcnemar(ttk, exact=True)
-    with pytest.deprecated_call():
+    with pytest.warns(FutureWarning):
         res1 = lzip(*[sbmcnemar(ttk[:, :, i], exact=True) for i in range(3)])
     assert_allclose(res, res1, rtol=1e-13)
 
@@ -171,7 +170,7 @@ def test_cochransq():
     #equivalence of mcnemar and cochranq for 2 samples
     a,b = x[:,:2].T
     res = cochrans_q(x[:, :2])
-    with pytest.deprecated_call():
+    with pytest.warns(FutureWarning):
         assert_almost_equal(sbmcnemar(a, b, exact=False, correction=False),
                             [res.statistic, res.pvalue])
 
@@ -391,9 +390,15 @@ def test_rank_compare_2indep1():
     assert_allclose(res_ub[1], 0.05, rtol=1e-13)
 
     # test consistency of tost and confint
-    res_tost = res.tost_prob_superior(*ci)
-    assert_allclose(res_tost.results_smaller.pvalue, 0.025, rtol=1e-13)
+    # lower margin is binding, alternative larger
+    res_tost = res.tost_prob_superior(ci[0], ci[1] * 1.05)
     assert_allclose(res_tost.results_larger.pvalue, 0.025, rtol=1e-13)
+    assert_allclose(res_tost.pvalue, 0.025, rtol=1e-13)
+
+    # upper margin is binding, alternative smaller
+    res_tost = res.tost_prob_superior(ci[0] * 0.85, ci[1])
+    assert_allclose(res_tost.results_smaller.pvalue, 0.025, rtol=1e-13)
+    assert_allclose(res_tost.pvalue, 0.025, rtol=1e-13)
 
     # use t-distribution
     # our ranking is defined as reversed from lawstat, and BM article
@@ -419,9 +424,15 @@ def test_rank_compare_2indep1():
     assert_allclose(res_ub[1], 0.05, rtol=1e-11)
 
     # test consistency of tost and confint
-    res_tost = res.tost_prob_superior(*ci)
-    assert_allclose(res_tost.results_smaller.pvalue, 0.025, rtol=1e-11)
-    assert_allclose(res_tost.results_larger.pvalue, 0.025, rtol=1e-11)
+    # lower margin is binding, alternative larger
+    res_tost = res.tost_prob_superior(ci[0], ci[1] * 1.05)
+    assert_allclose(res_tost.results_larger.pvalue, 0.025, rtol=1e-10)
+    assert_allclose(res_tost.pvalue, 0.025, rtol=1e-10)
+
+    # upper margin is binding, alternative smaller
+    res_tost = res.tost_prob_superior(ci[0] * 0.85, ci[1])
+    assert_allclose(res_tost.results_smaller.pvalue, 0.025, rtol=1e-10)
+    assert_allclose(res_tost.pvalue, 0.025, rtol=1e-10)
 
     # extras
     # cohen's d
