@@ -341,8 +341,13 @@ def test_instantiation_valid():
             warnings.simplefilter("error")
 
             for ix, freq in supported_date_indexes:
-                endog = base_endog.copy()
-                endog.index = ix
+                # Avoid warnings due to Series with object dtype
+                if isinstance(ix, pd.Series) and ix.dtype == object:
+                    with warnings.catch_warnings():
+                        warnings.simplefilter("ignore")
+                        endog = pd.DataFrame(base_endog, index=ix)
+                else:
+                    endog = pd.DataFrame(base_endog, index=ix)
 
                 mod = tsa_model.TimeSeriesModel(endog, freq=freq)
                 if freq is None:
@@ -427,8 +432,9 @@ def test_instantiation_valid():
 
         # Unsupported (but valid) indexes, should all give warnings
         message = (
-            "An unsupported index was provided and will be"
-            " ignored when e.g. forecasting."
+            "An unsupported index was provided. As a result, forecasts "
+            "cannot be generated. To use the model for forecasting, use "
+            "one of the supported classes of index."
         )
         with warnings.catch_warnings(record=True) as w:
             warnings.simplefilter("always")
@@ -1127,8 +1133,9 @@ def test_custom_index():
         np.random.normal(size=5), index=["a", "b", "c", "d", "e"]
     )
     message = (
-        "An unsupported index was provided and will be ignored when"
-        " e.g. forecasting."
+        "An unsupported index was provided. As a result, forecasts cannot be "
+        "generated. To use the model for forecasting, use one of the "
+        "supported classes of index."
     )
     with warnings.catch_warnings(record=True) as w:
         warnings.simplefilter("always")
