@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from statsmodels.compat.pandas import (
     is_float_index,
     is_int_index,
@@ -106,7 +108,7 @@ def get_index_loc(key, index):
                 start=base_index_start, stop=stop, step=base_index_step
             )
 
-    # Special handling for integral indices
+    # Special handling for NumericIndex
     if (
         not range_index
         and int_index
@@ -145,7 +147,7 @@ def get_index_loc(key, index):
                 key = index[key]
         # Other key types (i.e. string date or some datetime-like object)
         else:
-            # Covert the key to the appropriate date-like object
+            # Convert the key to the appropriate date-like object
             if index_class is PeriodIndex:
                 date_key = Period(key, freq=base_index.freq)
             else:
@@ -175,9 +177,9 @@ def get_index_loc(key, index):
         # (note that get_loc will throw a KeyError if key is invalid)
         loc = index.get_loc(key)
     elif int_index or range_index:
-        # For integral indices and RangeIndex, key is assumed to be the
-        # location and not an index value (this assumption is required to
-        # support RangeIndex)
+        # For NumericIndex and RangeIndex, key is assumed to be the location
+        # and not an index value (this assumption is required to support
+        # RangeIndex)
         try:
             index[key]
         # We want to raise a KeyError in this case, to keep the exception
@@ -216,7 +218,7 @@ def get_index_label_loc(key, index, row_labels):
     key : label
         The key for which to find the location if the underlying index is
         a DateIndex or is only being used as row labels, or a location if
-        the underlying index is a RangeIndex or an integral index.
+        the underlying index is a RangeIndex or a NumericIndex.
     index : pd.Index
         The index to search.
     row_labels : pd.Index
@@ -290,7 +292,7 @@ def get_prediction_index(
     index_none=False,
     index_generated=None,
     data=None,
-):
+) -> tuple[int, int, int, Index | None]:
     """
     Get the location of a specific key in an index or model row labels
 
@@ -346,7 +348,7 @@ def get_prediction_index(
 
     This difference in behavior is necessary to support `RangeIndex`. This
     is because integers for a RangeIndex could refer either to index values
-    or to index locations in an ambiguous way (while for integral indices,
+    or to index locations in an ambiguous way (while for `NumericIndex`,
     since we have required them to be full indexes, there is no ambiguity).
     """
 
@@ -416,7 +418,7 @@ def get_prediction_index(
         # If we are in sample, and have row labels, use them
         if data.row_labels is not None and not (start_oos or end_oos):
             prediction_index = data.row_labels[start : end + 1]
-        # Otherwise, warn the user that they will get an integral index
+        # Otherwise, warn the user that they will get an NumericIndex
         else:
             if not silent:
                 warnings.warn(
@@ -431,7 +433,7 @@ def get_prediction_index(
                 " version, calling this method in a model"
                 " without a supported index will result in an"
                 " exception.",
-                DeprecationWarning,
+                FutureWarning,
                 stacklevel=2,
             )
     elif index_none:
@@ -485,19 +487,19 @@ class TimeSeriesModel(base.LikelihoodModel):
         Notes
         -----
         Creates `self._index` and related attributes. `self._index` is always
-        a Pandas index, and it is always an integral index, DatetimeIndex, or
+        a Pandas index, and it is always NumericIndex, DatetimeIndex, or
         PeriodIndex.
 
         If Pandas objects, endog / exog may have any type of index. If it is
-        an integral index with values 0, 1, ..., nobs-1 or if it is (coerceable
-        to) a DatetimeIndex or PeriodIndex *with an associated frequency*, then
-        it is called a "supported" index. Otherwise it is called an
-        "unsupported" index.
+        an NumericIndex with values 0, 1, ..., nobs-1 or if it is (coerceable to)
+        a DatetimeIndex or PeriodIndex *with an associated frequency*, then it
+        is called a "supported" index. Otherwise it is called an "unsupported"
+        index.
 
         Supported indexes are standardized (i.e. a list of date strings is
         converted to a DatetimeIndex) and the result is put in `self._index`.
 
-        Unsupported indexes are ignored, and a supported integral index is
+        Unsupported indexes are ignored, and a supported NumericIndex is
         generated and put in `self._index`. Warnings are issued in this case
         to alert the user if the returned index from some operation (e.g.
         forecasting) is different from the original data's index. However,
@@ -507,7 +509,7 @@ class TimeSeriesModel(base.LikelihoodModel):
         The benefit of supported indexes is that they allow *forecasting*, i.e.
         it is possible to extend them in a reasonable way. Thus every model
         must have an underlying supported index, even if it is just a generated
-        integral index.
+        NumericIndex.
         """
 
         # Get our index from `dates` if available, otherwise from whatever
@@ -610,7 +612,7 @@ class TimeSeriesModel(base.LikelihoodModel):
                     resampled_index = date_range(
                         start=index[0], end=index[-1], freq=freq
                     )
-                    if not inferred_freq and not resampled_index.equals(index):
+                    if not inferred_freq and not (resampled_index == index).all():
                         raise ValueError(
                             "The given frequency argument could"
                             " not be matched to the given index."
@@ -657,8 +659,9 @@ class TimeSeriesModel(base.LikelihoodModel):
         # Issue warnings for unsupported indexes
         if has_index and not (date_index or range_index or is_increment):
             warnings.warn(
-                "An unsupported index was provided and will be"
-                " ignored when e.g. forecasting.",
+                "An unsupported index was provided. As a result, forecasts "
+                "cannot be generated. To use the model for forecasting, use one "
+                "of the supported classes of index.",
                 ValueWarning,
                 stacklevel=2,
             )
@@ -713,7 +716,7 @@ class TimeSeriesModel(base.LikelihoodModel):
         key : label
             The key for which to find the location if the underlying index is
             a DateIndex or a location if the underlying index is a RangeIndex
-            or an integral index.
+            or an NumericIndex.
         base_index : pd.Index, optional
             Optionally the base index to search. If None, the model's index is
             searched.
@@ -731,7 +734,7 @@ class TimeSeriesModel(base.LikelihoodModel):
         Notes
         -----
         If `key` is past the end of of the given index, and the index is either
-        an integral index or a date index, this function extends the index up to
+        an NumericIndex or a date index, this function extends the index up to
         and including key, and then returns the location in the new index.
         """
 
@@ -748,7 +751,7 @@ class TimeSeriesModel(base.LikelihoodModel):
         key : label
             The key for which to find the location if the underlying index is
             a DateIndex or is only being used as row labels, or a location if
-            the underlying index is a RangeIndex or an integral index.
+            the underlying index is a RangeIndex or an NumericIndex.
         base_index : pd.Index, optional
             Optionally the base index to search. If None, the model's index is
             searched.
@@ -774,7 +777,7 @@ class TimeSeriesModel(base.LikelihoodModel):
             base_index = self._index
         return get_index_label_loc(key, base_index, self.data.row_labels)
 
-    def _get_prediction_index(self, start, end, index=None, silent=False):
+    def _get_prediction_index(self, start, end, index=None, silent=False) -> tuple[int, int, int, Index | None]:
         """
         Get the location of a specific key in an index or model row labels
 
@@ -827,7 +830,7 @@ class TimeSeriesModel(base.LikelihoodModel):
 
         This difference in behavior is necessary to support `RangeIndex`. This
         is because integers for a RangeIndex could refer either to index values
-        or to index locations in an ambiguous way (while for integral indices,
+        or to index locations in an ambiguous way (while for `NumericIndex`,
         since we have required them to be full indexes, there is no ambiguity).
         """
         nobs = len(self.endog)
@@ -851,6 +854,7 @@ class TimeSeriesModel(base.LikelihoodModel):
             vals = [vals]
         self.data.xnames = vals
 
+    # TODO: This is an antipattern, fix/remove with VAR
     # overwrite with writable property for (V)AR models
     exog_names = property(
         _get_exog_names,
