@@ -5,10 +5,10 @@ from __future__ import annotations
 
 from statsmodels.compat.numpy import lstsq
 from statsmodels.compat.pandas import deprecate_kwarg
-from statsmodels.compat.python import Literal, lzip
+from statsmodels.compat.python import lzip
 from statsmodels.compat.scipy import _next_regular
 
-from typing import Union, List
+from typing import Literal, Union
 import warnings
 
 import numpy as np
@@ -40,7 +40,7 @@ from statsmodels.tsa._innovations import innovations_algo, innovations_filter
 from statsmodels.tsa.adfvalues import mackinnoncrit, mackinnonp
 from statsmodels.tsa.tsatools import add_trend, lagmat, lagmat2ds
 
-ArrayLike1D = Union[np.ndarray, pd.Series, List[float]]
+ArrayLike1D = Union[np.ndarray, pd.Series, list[float]]
 
 __all__ = [
     "acovf",
@@ -645,7 +645,9 @@ def acf(
         (nlags+1,).
     confint : ndarray, optional
         Confidence intervals for the ACF at lags 0, 1, ..., nlags. Shape
-        (nlags + 1, 2). Returned if alpha is not None.
+        (nlags + 1, 2). Returned if alpha is not None. The confidence
+        intervals are centered on the estimated ACF values. This behavior
+        differs from plot_acf which centers the confidence intervals on 0.
     qstat : ndarray, optional
         The Ljung-Box Q-Statistic for lags 1, 2, ..., nlags (excludes lag
         zero). Returned if q_stat is True.
@@ -674,6 +676,13 @@ def acf(
     .. [2] Brockwell and Davis, 1987. Time Series Theory and Methods
     .. [3] Brockwell and Davis, 2010. Introduction to Time Series and
        Forecasting, 2nd edition.
+
+    See Also
+    --------
+    statsmodels.tsa.stattools.acf
+        Estimate the autocorrelation function.
+    statsmodels.graphics.tsaplots.plot_acf
+        Plot autocorrelations and confidence intervals.
     """
     adjusted = bool_like(adjusted, "adjusted")
     nlags = int_like(nlags, "nlags", optional=True)
@@ -994,7 +1003,9 @@ def pacf(
     statsmodels.tsa.stattools.pacf_ols
         Partial autocorrelation estimation using OLS.
     statsmodels.tsa.stattools.pacf_burg
-        Partial autocorrelation estimation using Burg"s method.
+        Partial autocorrelation estimation using Burg's method.
+    statsmodels.graphics.tsaplots.plot_pacf
+        Plot partial autocorrelations and confidence intervals.
 
     Notes
     -----
@@ -1620,7 +1631,7 @@ def grangercausalitytests(x, maxlag, addconst=True, verbose=None):
             or res2djoint.params.shape[0] != dtajoint.shape[1]
         ):
             raise InfeasibleTestError(
-                "The Granger causality test statistic cannot be compute "
+                "The Granger causality test statistic cannot be computed "
                 "because the VAR has a perfect fit of the data."
             )
         fgc1 = (
@@ -2545,7 +2556,7 @@ class ZivotAndrewsUnitRoot:
         # first-diff y and standardize for numerical stability
         endog = np.diff(series, axis=0)
         endog /= np.sqrt(endog.T.dot(endog))
-        series /= np.sqrt(series.T.dot(series))
+        series = series / np.sqrt(series.T.dot(series))
         # reserve exog space
         exog = np.zeros((endog[lags:].shape[0], cols + lags))
         exog[:, 0] = const
@@ -2653,7 +2664,7 @@ class ZivotAndrewsUnitRoot:
            great crash, the oil-price shock, and the unit-root hypothesis.
            Journal of Business & Economic Studies, 10: 251-270.
         """
-        x = array_like(x, "x")
+        x = array_like(x, "x", dtype=np.double, ndim=1)
         trim = float_like(trim, "trim")
         maxlag = int_like(maxlag, "maxlag", optional=True)
         regression = string_like(
